==> Remmina-v1.3.6.tar.gz: Remmina-v1.3.6/src/rmnews.h <==
/*
 * Remmina - The GTK+ Remote Desktop Client
 * Copyright (C) 2016-2019 Antenore Gatta, Giovanni Panozzo
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 *  In addition, as a special exception, the copyright holders give
 *  permission to link the code of portions of this program with the
 *  OpenSSL library under certain conditions as described in each
 *  individual source file, and distribute linked combinations
 *  including the two.
 *  You must obey the GNU General Public License in all respects
 *  for all of the code used other than OpenSSL. *  If you modify
 *  file(s) with this exception, you may extend this exception to your
 *  version of the file(s), but you are not obligated to do so. *  If you
 *  do not wish to do so, delete this exception statement from your
 *  version. *  If you delete this exception statement from all source
 *  files in the program, then also delete it here.
 *
 */

typedef struct _RemminaNewsDialog {
	GtkBuilder *	builder;
	GtkDialog *	dialog;

	GtkTextView *	rmnews_text_view;
	GtkLabel *	rmnews_label;
	GtkButton *	rmnews_button_close;
	GtkLabel *	rmnews_stats_label;
	GtkSwitch *	rmnews_stats_switch;
	GtkLabel *	rmnews_defaultcl_label;
	GtkButton *	rmnews_defaultcl_button;

	gint		retval;
} RemminaNewsDialog;

#pragma once

G_BEGIN_DECLS
void rmnews_schedule();
void rmnews_get_url(const char *url);
G_END_DECLS

==> Remmina-v1.4.26.tar.gz: Remmina-v1.4.26/src/rmnews.h <==
/*
 * Remmina - The GTK+ Remote Desktop Client
 * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 *  In addition, as a special exception, the copyright holders give
 *  permission to link the code of portions of this program with the
 *  OpenSSL library under certain conditions as described in each
 *  individual source file, and distribute linked combinations
 *  including the two.
 *  You must obey the GNU General Public License in all respects
 *  for all of the code used other than OpenSSL. *  If you modify
 *  file(s) with this exception, you may extend this exception to your
 *  version of the file(s), but you are not obligated to do so. *  If you
 *  do not wish to do so, delete this exception statement from your
 *  version. *  If you delete this exception statement from all source
 *  files in the program, then also delete it here.
 *
 */

typedef struct _RemminaNewsDialog {
	GtkBuilder *	builder;
	GtkDialog *	dialog;

	GtkTextView *	rmnews_text_view;
	GtkLabel *	rmnews_label;
	GtkButton *	rmnews_button_close;
	GtkLabel *	rmnews_defaultcl_label;
	GtkButton *	rmnews_defaultcl_button;
	GtkSwitch *	rmnews_news_switch;

	gint		retval;
} RemminaNewsDialog;

#pragma once

G_BEGIN_DECLS
extern gboolean disablenews;
void rmnews_schedule();
void rmnews_show_news();
void rmnews_get_url(const char *url);
G_END_DECLS
